@@ -704,19 +704,19 @@ class LinearAttention(nn.Module):
         self.to_q = nn.Sequential(
             nn.Dropout(dropout),
             nn.Conv2d(dim, inner_dim, 1, bias = False),
-            nn.Conv2d(inner_dim, inner_dim, 3, bias = False, padding = 1)
+            nn.Conv2d(inner_dim, inner_dim, 3, bias = False, padding = 1, groups = inner_dim)
         )
 
         self.to_k = nn.Sequential(
             nn.Dropout(dropout),
             nn.Conv2d(dim, inner_dim, 1, bias = False),
-            nn.Conv2d(inner_dim, inner_dim, 3, bias = False, padding = 1)
+            nn.Conv2d(inner_dim, inner_dim, 3, bias = False, padding = 1, groups = inner_dim)
         )
 
         self.to_v = nn.Sequential(
             nn.Dropout(dropout),
             nn.Conv2d(dim, inner_dim, 1, bias = False),
-            nn.Conv2d(inner_dim, inner_dim, 3, bias = False, padding = 1)
+            nn.Conv2d(inner_dim, inner_dim, 3, bias = False, padding = 1, groups = inner_dim)
         )
 
         self.to_out = nn.Sequential(
